@@ -1,5 +1,5 @@
 /*---[ druid.c ]------------------------------------------------------
- * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
+ * Copyright (C) 2000, 2001 Tomas Junnonen (majix@sci.fi)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@ static GdkImlibImage *watermark;
 static GdkColor white;
 static GdkColor black;
 GList *devicelist = NULL;
+gboolean advanced = FALSE;
 gboolean masq = TRUE;
 gboolean tos = TRUE;
 
@@ -94,62 +95,49 @@ fill_devicelist (void)
 	devicelist = device_exists ("brg1");
 	devicelist = device_exists ("brg2");
 	devicelist = device_exists ("brg3");
+	devicelist = device_exists ("ipsec0");
+	devicelist = device_exists ("ipsec1");
+	devicelist = device_exists ("ipsec2");
+	devicelist = device_exists ("ipsec3");
 }
 
-/* [ masq_next ]
- * Check that the external and internal devices aren't the same when next
- * is pressed on the masq page
+/* [ jump_to ]
+ * Jump to a given page in a druid
  */
 static gint
-masq_next (GnomeDruidPage *druidpage, gpointer druid, Druid *data)
+jump_to (GnomeDruidPage *currentpage, gpointer druid, GnomeDruidPage *page)
 {
-	gchar *device = gtk_entry_get_text (GTK_ENTRY (data->extdevice));
-	gchar *intdevice = gtk_entry_get_text (GTK_ENTRY (data->intdevice));
-	gboolean masqsensitive = GTK_WIDGET_IS_SENSITIVE (data->masq);
-
-	if (masqsensitive && !g_strcasecmp (device, intdevice)) {
-		GtkWidget *dialog=gnome_error_dialog (_(
-			"The external and internal network interfaces\n"
-			"can't be the same. Please change one of them,\n"
-			"or alternatively disable IP Masquerading."));
-		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+		gnome_druid_set_page (GNOME_DRUID (druid), page);
 		return TRUE;
-	}
-	masq = TRUE;
-	return FALSE;
 }
 
-/* [ device_next ]
- * Handle the druid event flow when the next button is pressed on the device
- * page, skip the masq page if only one device present.
+/* [ branch_next ]
+ * Special flow case: From branch we either go to the advanced device page
+ * or the simple device page
  */
+
 static gint
-device_next (GnomeDruidPage *druidpage, gpointer druid, GnomeDruidPage *servicepage)
+set_page (GnomeDruidPage *currentpage, gpointer druid,
+	     GnomeDruidPage *nextpage)
 {
-	GList *last;
-	gboolean showall;
-
-	last = g_list_last (devicelist);
-	showall = gnome_config_get_bool ("firestarter/Druid/showall=FALSE");
-
-	if (g_list_position (devicelist, last) || showall)
+	if (advanced)
 		return FALSE;
 	else {
-		gnome_druid_set_page (GNOME_DRUID (druid), servicepage);
-		masq = FALSE;
+		gnome_druid_set_page (GNOME_DRUID (druid), nextpage);
 		return TRUE;
 	}
 }
 
+
 /* [ services_back ]
- * Called when the back button is pressed on the services page. Skips the masq
- * page if necessary
+ * Special flow case: From the services page we either go back to the simple
+ * devices page or the previous default advanced screen.
  */
 static gint
-services_back (GnomeDruidPage *druidpage, gpointer druid,
+services_back (GnomeDruidPage *currentpage, gpointer druid,
 	       GnomeDruidPage *devicepage)
 {
-	if (masq)
+	if (advanced)
 		return FALSE;
 	else {
 		gnome_druid_set_page (GNOME_DRUID (druid), devicepage);
@@ -201,8 +189,73 @@ turn_white (GtkWidget *page)
 	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD (page), &black);
 }
 
+static void
+set_skill (GtkToggleButton *button)
+{
+	advanced = gtk_toggle_button_get_active (button);
+}
+
+/* [ create_branch_page ]
+ * Create the contents of the skill level branch page
+ */
+static GtkWidget*
+create_branch_page (Druid *data)
+{
+	GtkWidget *page;
+	GtkWidget *table;
+	GtkWidget *label;
+	GtkWidget *vbox;
+	GtkWidget *radio1;
+
+	page = gnome_druid_page_standard_new_with_vals (_("Choose your skill level"), NULL);
+	turn_white (page);
+
+	table = gtk_table_new (1, 2, FALSE);
+	gtk_table_set_row_spacings (GTK_TABLE(table), GNOME_PAD_SMALL);
+	gtk_table_set_col_spacings (GTK_TABLE(table), GNOME_PAD_SMALL);
+
+	label = gtk_label_new (_(
+		"Please choose the skill level best suited to you.\n\n"
+		"Simple is recommended for most workstation users with a single computer.\n"
+		"Advanced presents you with more options and is meant for experienced users\n"
+		"with machines acting as gateways."));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+		GTK_FILL, GTK_FILL, GNOME_PAD, GNOME_PAD);
+
+	vbox = gtk_vbox_new (FALSE, 1);
+	gtk_table_attach (GTK_TABLE (table), vbox, 0, 1, 1, 2,
+		GTK_FILL, GTK_FILL, GNOME_PAD, 2);
+
+	radio1 = gtk_radio_button_new_with_label (NULL,
+		_("Simple firewall setup"));
+	gtk_table_attach (GTK_TABLE (table), radio1, 0, 1, 2, 3,
+		GTK_FILL, GTK_FILL, GNOME_PAD, 0);
+//	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio1),
+//		!gnome_config_get_bool ("/firestarter/Druid/advanced=FALSE"));
+
+	data->advanced = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio1),
+		_("Advanced firewall setup"));
+	gtk_table_attach (GTK_TABLE (table), data->advanced, 0, 1, 3, 4,
+		GTK_FILL, GTK_FILL, GNOME_PAD, GNOME_PAD_SMALL);
+	gtk_signal_connect (GTK_OBJECT (data->advanced), "toggled",
+		GTK_SIGNAL_FUNC (set_skill), NULL);
+//	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->advanced),
+//		gnome_config_get_bool ("/firestarter/Druid/advanced=FALSE"));
+
+	gtk_widget_show_all (table);
+
+	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page)->vbox),
+		table, TRUE, TRUE, 0);
+
+	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD (page), &white);
+
+	return (page);
+}
+
 /* [ create_device_page ]
- * Create the contents of the device selection page
+ * Create the contents of the simple device selection page
  */
 static GtkWidget*
 create_device_page (Druid *data)
@@ -570,7 +623,7 @@ create_services_page (Druid *data)
 	gtk_box_pack_start (GTK_BOX (vbox), data->ipsec, FALSE, FALSE, 0);
 
 	gtk_box_pack_start (GTK_BOX (data->services), vbox, FALSE, FALSE, 0);
-	
+
 	gtk_widget_show_all (table);
 
 	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page)->vbox),
@@ -662,7 +715,7 @@ create_icmp_page (Druid *data)
 
 	data->icmp_redir = gtk_check_button_new_with_label ("Redirection");
 	gtk_box_pack_start (GTK_BOX (vbox), data->icmp_redir, FALSE, FALSE, 0);
-	
+
 	data->icmp_quench = gtk_check_button_new_with_label ("Source Quenches");
 	gtk_box_pack_start (GTK_BOX (vbox), data->icmp_quench, FALSE, FALSE, 0);
 
@@ -695,7 +748,7 @@ create_tos_page (Druid *data)
 		"Type of Service (ToS) Configuration"), NULL);
 
 	turn_white (page);
-		
+
 	table = gtk_table_new (4, 1, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE(table), GNOME_PAD_SMALL);
 	gtk_table_set_col_spacings (GTK_TABLE(table), GNOME_PAD_SMALL);
@@ -740,7 +793,7 @@ create_tos_page (Druid *data)
 	gtk_tooltips_set_tip (ttips, data->tos_client, _(
 		"Check this option to enable Type of Service flags for common "
 		"client applications, such as WWW, FTP, SSH & E-Mail."), "");
- 
+
 	data->tos_server = gtk_check_button_new_with_label ("Server Applications");
 	gtk_box_pack_start (GTK_BOX (vbox), data->tos_server, FALSE, FALSE, 0);
 
@@ -756,7 +809,7 @@ create_tos_page (Druid *data)
 		"for `Throughput' for both X and SSHd."
 		"You should select this ONLY if you need to run X over your link"), "");
 
-	gtk_box_pack_start (GTK_BOX (data->tos), vbox, FALSE, FALSE, 0);   
+	gtk_box_pack_start (GTK_BOX (data->tos), vbox, FALSE, FALSE, 0);
 
 	/* Column 2 */
 	vbox = gtk_vbox_new (FALSE, 1);
@@ -881,6 +934,7 @@ rundruid (void)
 	GtkWidget *app = NULL;
 	GtkWidget *druid;
 	GtkWidget *startpage;
+	GtkWidget *branchpage;
 	GtkWidget *devicepage;
 	GtkWidget *masqpage;
 	GtkWidget *tospage;
@@ -934,6 +988,7 @@ rundruid (void)
 
 	/* Create the basic druid pages */
 	startpage = create_start_page ();
+	branchpage = create_branch_page (data);
 	devicepage = create_device_page (data);
 	masqpage = create_masq_page (data);
 	tospage = create_tos_page (data);
@@ -941,29 +996,43 @@ rundruid (void)
 	icmppage = create_icmp_page (data);
 	finishpage = create_finish_page ();
 
-	/* Signals to alter the druid event flow*/
+
+	/* Signals to save choices and terminate druid */
 	gtk_signal_connect (GTK_OBJECT (finishpage), "finish",
-			    GTK_SIGNAL_FUNC (write_script), data);
+		GTK_SIGNAL_FUNC (write_script), data);
 
 	gtk_signal_connect_object (GTK_OBJECT (finishpage), "finish",
 		GTK_SIGNAL_FUNC (quit_druid), GTK_OBJECT (app));
 
-	gtk_signal_connect (GTK_OBJECT (masqpage), "next",
-			    GTK_SIGNAL_FUNC (masq_next), data);
+	/* Signal logic to alter the druid event flow*/
 
-	gtk_signal_connect (GTK_OBJECT (devicepage), "next",
-			    GTK_SIGNAL_FUNC (device_next), servicespage);
+	/* 
+	Simple:   Start, Branch, Network, ICMP, Services
+	Advanced: Start, Branch, Network, ICMP, Services, (Sysctl), ToS, Masquerading, (PortfwScript)
+	*/
 
-	gtk_signal_connect (GTK_OBJECT (servicespage), "back",
-			    GTK_SIGNAL_FUNC (services_back), devicepage);
+	/* Services -> Finish */
+	gtk_signal_connect (GTK_OBJECT (servicespage), "next",
+		GTK_SIGNAL_FUNC (set_page), finishpage);
 
-	/* Add the pages to the druid, controls the order */
+	/* Services <- Finish */
+	gtk_signal_connect (GTK_OBJECT (finishpage), "back",
+		GTK_SIGNAL_FUNC (set_page), servicespage);
+
+	/* Add the pages to the druid */
+	/* common pages to both branches */
 	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (startpage));
+	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (branchpage));
 	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (devicepage));
-	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (masqpage));
-	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (tospage));
-	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (servicespage));
 	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (icmppage));
+	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (servicespage));
+
+	/* Pages only in the advanced branch */
+	/* SYSCTL PAGE GOES HERE */
+	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (tospage));
+	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (masqpage));
+	/* PORTFWSCRIPT PAGE GOES HERE*/
+
 	gnome_druid_append_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (finishpage));
 
 	/* Set page to start from */
