@@ -22,9 +22,11 @@ struct _Druid
 	GtkWidget *extdevice;
 	GtkWidget *intdevice;
 	GtkWidget *intrange;
+	GtkWidget *advanced;
 
 	GtkWidget *auto_int_ip;
 
+        GtkWidget *sysctl;
 	GtkWidget *services;
 	GtkWidget *icmp;
 	GtkWidget *tos;
