@@ -14,6 +14,8 @@
 #include <status-docklet.h>
 #include <sys/stat.h>
 #include <stdio.h>
+#include <netdb.h>
+#include <sys/socket.h>
 #include <errno.h>
 
 #include "firestarter.h"
@@ -138,12 +140,12 @@ hide_window_cb (GtkWidget *window, GdkEventButton* bevent)
 }
 
 /* [ stop_firewall ]
- * Flushes, zeroes and sets the default policy of the chains
+ * Flushes, zeroes and sets all policies to accept
  */
 void
 stop_firewall (void)
 {
-	gchar *soundfile;
+	/* gchar *soundfile; */
 	gchar *sbin;
 	gchar *command = NULL;
 
@@ -191,12 +193,13 @@ stop_firewall (void)
 	set_panel_pic (statustopped_xpm);
 	appbar_update ("stop");
 
-	if (gnome_config_get_bool ("/firestarter/Sounds/enablesounds=TRUE")) {
+/*	if (gnome_config_get_bool ("/firestarter/Sounds/enablesounds=FALSE")) {
 		soundfile = gnome_config_get_string (
 			"/firestarter/Sounds/stopsoundfile=");
 		gnome_sound_play (soundfile);
 		g_free (soundfile);
 	}
+*/
 }
 
 /* [ restart_firewall ]
@@ -208,7 +211,7 @@ restart_firewall (void)
 	gchar *commandline = g_strjoin (NULL, "/bin/sh ",
 		FIRESTARTER_RULES_DIR "/firestarter/firewall.sh",
 		NULL);
-	gchar *soundfile;
+/*	gchar *soundfile; */
 
 	if (geteuid ()) {
 		GtkWidget *dialog=gnome_error_dialog (_(
@@ -224,16 +227,17 @@ restart_firewall (void)
 	g_free (commandline);
 	appbar_update ("start");
 
-	if (gnome_config_get_bool ("/firestarter/Sounds/enablesounds=TRUE")) {
+/*	if (gnome_config_get_bool ("/firestarter/Sounds/enablesounds=FALSE")) {
 		soundfile = gnome_config_get_string (
 			"/firestarter/Sounds/restartsoundfile");
 		gnome_sound_play (soundfile);
 		g_free (soundfile);
 	}
+*/
 }
 
 /* [ halt_traffic ]
- * Flushes and sets all policys to deny
+ * Flushes and sets all policies to deny
  */
 void
 halt_traffic (void)
@@ -248,7 +252,7 @@ halt_traffic (void)
 		return;
 	}
 
-	if (gnome_config_get_bool ("/firestarter/Druid/locatesbins=FALSE"))
+	if (gnome_config_get_bool ("/firestarter/Druid/locatesbins=TRUE"))
 		if (NETFILTER)
 			sbin = g_strdup ("`which iptables`");
 		else
@@ -510,6 +514,7 @@ main (int argc, char* argv[])
 	gchar *allowsmtitles[1];
 	gchar *allowsatitles[1];
 
+	gchar hostname[40];
 	gint i;
 	CORBA_Environment ev;
 	CORBA_ORB orb;
@@ -530,7 +535,14 @@ main (int argc, char* argv[])
 	CORBA_exception_init (&ev);
 	orb = gnome_CORBA_init (PACKAGE, VERSION, &argc, argv, 0, &ev);
 
-	window = gnome_app_new (PACKAGE, "Firestarter");
+
+	/* Create the main window, append hostname to title */
+	if (!gethostname (hostname, 39))
+		window = gnome_app_new (PACKAGE, g_strconcat ("Firestarter ", hostname, NULL));
+	else
+		window = gnome_app_new (PACKAGE, "Firestarter");
+
+
 	NETFILTER = detect_netfilter ();
 
 	ttips = gtk_tooltips_new ();
@@ -552,10 +564,8 @@ main (int argc, char* argv[])
 	gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 			    GTK_SIGNAL_FUNC (closewindow), NULL);
 
-	#if GNOME_LIBS_VERSION>=60
 	gnome_window_icon_set_default_from_file (
 		"/usr/share/pixmaps/firestarter.png");
-	#endif
 
 	install_menus_and_toolbar (window);
 
