@@ -36,15 +36,17 @@ GtkWidget *exitonclose;
 GtkWidget *starthidden;
 GtkWidget *removedups;
 
+/*
 GtkWidget *enablesounds;
 GtkWidget *hitsoundentry;
 GtkWidget *stopsoundentry;
 GtkWidget *restartsoundentry;
+*/
 
 GtkWidget *logclist;
 
 GtkWidget *showall;
-GtkWidget *outfilter;
+GtkWidget *experiments;
 GtkWidget *locatesbins;
 GtkWidget *selectdeny;
 GtkWidget *selectreject;
@@ -54,11 +56,13 @@ GtkWidget *filesel;
 gboolean ifo = FALSE;
 
 static GtkWidget *create_browse_button (GtkWidget *button, gint which);
+/*
 static void 	 create_filesel	       (GtkWidget *widget, gpointer data);
 static void	 set_file_log	       (GtkWidget *widget, gpointer data);
 static void	 set_file_hit	       (GtkWidget *widget, gpointer data);
 static void 	 set_file_stop	       (GtkWidget *widget, gpointer data);
 static void 	 set_file_restart      (GtkWidget *widget, gpointer data);
+*/
 static void 	 give_false_ifo	       (GtkWidget *widget, gpointer data);
 static void 	 destroy_filesel       (GtkWidget *pbox,   gpointer data);
 
@@ -83,7 +87,7 @@ save_preferences (GnomePropertyBox *property_box, gint page_num, gint num)
 {
 /* TODO: This function is called 2 times when apply is pressed, why? */
 
-	gchar *logpath = FIRESTARTER_RULES_DIR "/firestarter/do-not-log-ports";
+	gchar *logpath = FIRESTARTER_RULES_DIR "/firestarter/block-ports";
 	FILE *f;
 	gchar *text;
 	gint i, j;
@@ -94,8 +98,9 @@ save_preferences (GnomePropertyBox *property_box, gint page_num, gint num)
     }
     
 /* General */
-	gnome_config_set_string ("/firestarter/Files/logfile",
+	/*gnome_config_set_string ("/firestarter/Files/logfile",
 		gtk_entry_get_text (GTK_ENTRY (logentry)));
+	*/
 
 	gnome_config_set_bool ("/firestarter/Program/startup",
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (startup)));
@@ -131,8 +136,8 @@ save_preferences (GnomePropertyBox *property_box, gint page_num, gint num)
 	gnome_config_set_bool ("/firestarter/Druid/showall",
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (showall)));
 
-	gnome_config_set_bool ("/firestarter/Druid/outfilter",
-		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (outfilter)));
+	gnome_config_set_bool ("/firestarter/Druid/experiments",
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (experiments)));
 
 	gnome_config_set_bool ("/firestarter/Druid/locatesbins",
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (locatesbins)));
@@ -144,7 +149,7 @@ save_preferences (GnomePropertyBox *property_box, gint page_num, gint num)
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (selectreject)));
 
 /* Sounds */
-	gnome_config_set_bool ("/firestarter/Sounds/enablesounds",
+/*	gnome_config_set_bool ("/firestarter/Sounds/enablesounds",
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (enablesounds)));
 
  	gnome_config_set_string ("/firestarter/Sounds/hitsoundfile",
@@ -155,7 +160,7 @@ save_preferences (GnomePropertyBox *property_box, gint page_num, gint num)
 
  	gnome_config_set_string ("/firestarter/Sounds/restartsoundfile",
 		gtk_entry_get_text (GTK_ENTRY (restartsoundentry)));
-
+*/
 	gnome_config_sync ();
 }
 
@@ -175,7 +180,6 @@ create_general_page (GtkWidget *pbox)
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 
 	frame = gtk_frame_new (_("General options"));
-	gtk_widget_set_usize (frame, 380, 170);
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
 			  GTK_FILL, GTK_FILL, GNOME_PAD, GNOME_PAD_SMALL);
 
@@ -239,17 +243,18 @@ create_general_page (GtkWidget *pbox)
 
 	return (table);
 }
-
+/*
 static void
 play_sound (GtkWidget *widget, GtkWidget *entry)
 {
 	gnome_sound_play (gtk_entry_get_text (GTK_ENTRY (entry)));
 }
-
+*/
 
 /* [ create_play_button ]
  * Convenience function to create a sound play button
  */
+ /*
 static GtkWidget*
 create_play_button (GtkWidget *button, GtkWidget *entry)
 {
@@ -266,11 +271,12 @@ create_play_button (GtkWidget *button, GtkWidget *entry)
 
 	return (button);
 }
-
+*/
 
 /* [ create_sounds_page ]
  * Create the sound property page
  */
+/*
 static GtkWidget*
 create_sounds_page (GtkWidget *pbox)
 {
@@ -286,7 +292,6 @@ create_sounds_page (GtkWidget *pbox)
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 
 	frame = gtk_frame_new (_("Sound options"));
-	gtk_widget_set_usize (frame, 380, 115);
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
 			  GTK_FILL, GTK_FILL, GNOME_PAD, GNOME_PAD_SMALL);
 
@@ -297,7 +302,7 @@ create_sounds_page (GtkWidget *pbox)
 	gtk_tooltips_set_tip (ttips, enablesounds, _(
 		"Check this if you want to hear sounds on certain events"), "");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (enablesounds),
-		gnome_config_get_bool ("/firestarter/Sounds/enablesounds=TRUE"));
+		gnome_config_get_bool ("/firestarter/Sounds/enablesounds=FALSE"));
 	gtk_box_pack_start (GTK_BOX (vbox), enablesounds, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 2);
@@ -370,6 +375,7 @@ create_sounds_page (GtkWidget *pbox)
 				   GTK_SIGNAL_FUNC (gnome_property_box_changed), GTK_OBJECT (pbox));
 	return (table);
 }
+*/
 
 static void
 log_add_clicked (GtkWidget *button, gpointer entry)
@@ -420,8 +426,7 @@ create_log_page (GtkWidget *pbox)
 	gtk_table_set_row_spacings (GTK_TABLE (table), 0);
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 
-	frame = gtk_frame_new (_("Never log these ports"));
-	gtk_widget_set_usize (frame, 195, 185);
+	frame = gtk_frame_new (_("Block these ports explicitly"));
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
 			  GTK_FILL, GTK_FILL, 0, GNOME_PAD_SMALL);
 
@@ -449,7 +454,6 @@ create_log_page (GtkWidget *pbox)
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
 	entry = gtk_entry_new ();
-	gtk_widget_set_usize (entry, 140, 22);
 	gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 1);
 
 	button = gtk_button_new_with_label (_("Add"));
@@ -465,6 +469,7 @@ create_log_page (GtkWidget *pbox)
 	gtk_signal_connect_object (GTK_OBJECT (button), "clicked",
 		GTK_SIGNAL_FUNC (gnome_property_box_changed), GTK_OBJECT (pbox));
 		
+/*
 	frame = gtk_frame_new (_("Misc. options"));
 	gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
 			  GTK_FILL, GTK_FILL, GNOME_PAD, GNOME_PAD_SMALL);
@@ -482,7 +487,6 @@ create_log_page (GtkWidget *pbox)
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
 	logentry = gtk_entry_new ();
-	gtk_widget_set_usize (logentry, 110, 20);
 	gtk_tooltips_set_tip (ttips, logentry, _(
 		"Enter the path to the file the syslog daemon logs to. "
 		"This is almost always /var/log/messages."), "");
@@ -505,6 +509,7 @@ create_log_page (GtkWidget *pbox)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (removedups),
 		gnome_config_get_bool ("/firestarter/Program/removedups=TRUE"));
 	gtk_box_pack_start (GTK_BOX (vbox), removedups, FALSE, FALSE, 5);
+	*/
 
 	gtk_signal_connect_object (GTK_OBJECT (removedups), "toggled",
 		GTK_SIGNAL_FUNC (gnome_property_box_changed), GTK_OBJECT (pbox));
@@ -525,7 +530,6 @@ create_advanced_page (GtkWidget *pbox)
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 
 	frame = gtk_frame_new (_("Wizard options"));
-	gtk_widget_set_usize (frame, 300, 100);
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
 			  GTK_FILL, GTK_FILL, GNOME_PAD, GNOME_PAD_SMALL);
 
@@ -539,13 +543,13 @@ create_advanced_page (GtkWidget *pbox)
 		gnome_config_get_bool ("/firestarter/Druid/showall=FALSE"));
 	gtk_box_pack_start (GTK_BOX (vbox), showall, FALSE, FALSE, 0);
 
-	outfilter = gtk_check_button_new_with_label (_("Filter Outbound Packets"));
-	gtk_tooltips_set_tip (ttips, outfilter, _(
-		"Check this and Firestarter will also filter Outbound packets. "
-		"Do not check unless you are sure you need it."), "");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (outfilter),
-		gnome_config_get_bool ("/firestarter/Druid/outfilter=FALSE"));
-	gtk_box_pack_start (GTK_BOX (vbox), outfilter, FALSE, FALSE, 0);
+	experiments = gtk_check_button_new_with_label (_("Enable Experimental Options"));
+	gtk_tooltips_set_tip (ttips, experiments, _(
+		"If you enable this, Firestarter can use some experimental patches for filtering,"
+		"Do not enable this option until you have read the manual for the pre-requisties"), "");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (experiments),
+		gnome_config_get_bool ("/firestarter/Druid/experiments=FALSE"));
+	gtk_box_pack_start (GTK_BOX (vbox), experiments, FALSE, FALSE, 0);
 
 	locatesbins = gtk_check_button_new_with_label (_("Try to detect the location of system binaries"));
 	gtk_tooltips_set_tip (ttips, locatesbins, _(
@@ -556,7 +560,6 @@ create_advanced_page (GtkWidget *pbox)
 	gtk_box_pack_start (GTK_BOX (vbox), locatesbins, FALSE, FALSE, 0);
 
 	frame = gtk_frame_new (_("Preferred packet rejection method"));
-	gtk_widget_set_usize (frame, 300, 70);
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 1, 2,
 			  GTK_FILL, GTK_FILL, GNOME_PAD, GNOME_PAD_SMALL);
 
@@ -586,7 +589,7 @@ create_advanced_page (GtkWidget *pbox)
 	gtk_signal_connect_object (GTK_OBJECT (showall), "toggled",
 		GTK_SIGNAL_FUNC (gnome_property_box_changed), GTK_OBJECT (pbox));
 
-	gtk_signal_connect_object (GTK_OBJECT (outfilter), "toggled",
+	gtk_signal_connect_object (GTK_OBJECT (experiments), "toggled",
 		GTK_SIGNAL_FUNC (gnome_property_box_changed), GTK_OBJECT (pbox));
  
 	gtk_signal_connect_object (GTK_OBJECT (locatesbins), "toggled",
@@ -648,7 +651,6 @@ preferences_cb (GtkWidget *widget, gpointer data)
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 
 	sections_clist = gtk_clist_new (1);
-	gtk_widget_set_usize (GTK_WIDGET (sections_clist), 100, 0);
 	gtk_clist_set_selection_mode (GTK_CLIST (sections_clist),
 				      GTK_SELECTION_BROWSE);
 
@@ -657,9 +659,11 @@ preferences_cb (GtkWidget *widget, gpointer data)
 
 	label = gtk_label_new ("Test");
 	prefs_add_section_page (_("General"), create_general_page (pbox), pbox);
-	prefs_add_section_page (_("Logging"), create_log_page (pbox), pbox);
-	prefs_add_section_page (_("Sounds"), create_sounds_page (pbox), pbox);
+	prefs_add_section_page (_("Blocking"), create_log_page (pbox), pbox);
+/*	prefs_add_section_page (_("Sounds"), create_sounds_page (pbox), pbox); */
 	prefs_add_section_page (_("Advanced"), create_advanced_page (pbox), pbox);
+	
+	gtk_clist_columns_autosize (GTK_CLIST (sections_clist) );
 
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (GNOME_PROPERTY_BOX (pbox)->notebook), FALSE);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (GNOME_PROPERTY_BOX (pbox)->notebook), FALSE);
@@ -696,7 +700,7 @@ preferences_cb (GtkWidget *widget, gpointer data)
 
 	gtk_widget_show_all (pbox);
 }
-
+/*
 static void
 set_file_log (GtkWidget *widget, gpointer data)
 {
@@ -704,6 +708,7 @@ set_file_log (GtkWidget *widget, gpointer data)
 			gtk_file_selection_get_filename (GTK_FILE_SELECTION (data)));
 }
 
+
 static void
 set_file_hit (GtkWidget *widget, gpointer data)
 {
@@ -724,13 +729,13 @@ set_file_restart (GtkWidget *widget, gpointer data)
 	gtk_entry_set_text (GTK_ENTRY (restartsoundentry),
 			gtk_file_selection_get_filename (GTK_FILE_SELECTION (data)));
 }
-
+*/
 static void
 give_false_ifo (GtkWidget *widget, gpointer data)
 {
 	ifo = FALSE;
 }
-
+/*
 static void
 create_filesel (GtkWidget *widget, gpointer data)
 {
@@ -765,10 +770,11 @@ create_filesel (GtkWidget *widget, gpointer data)
 
 	gtk_widget_show (filesel);
 }
-
+*/
 /* [ create_browse_button ]
  * Convenience function to create a browse button
  */
+/*
 static GtkWidget*
 create_browse_button (GtkWidget *button, gint which)
 {
@@ -780,7 +786,7 @@ create_browse_button (GtkWidget *button, gint which)
 
 	return (button);
 }
-
+*/
 /* [ destroy_filesel ]
  * Destroy the file selector window if open when the preference
  * window receive the any signal
