@@ -21,6 +21,7 @@ service (gint port, gint proto)
 {
 	struct servent *ent;
 
+	if (port == 135) return ("ms-rpc");
 	if (port == 31337) return ("borifice");
 	if (port == 12345) return ("netbus");
 	if (port == 12346) return ("netbus");
@@ -34,10 +35,9 @@ service (gint port, gint proto)
 	if (port == 16660) return ("stacheldraht");
 	if (port == 60001) return ("stacheldraht");
 
-
 	if (proto == 17)
 		ent = getservbyport (htons (port), "udp");
-	if (proto == 51)
+	else if (proto == 51)
 		ent = getservbyport (htons (port), "ah");
 	else
 		ent = getservbyport (htons (port), "tcp");
